'''This is just a joke'''

"""This is a function simplest you have ever seen"""
def print_lol(the_list):
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item)
        else:
            print(each_item)
