from distutils.core import setup

setup(
        name='jyw',
        version='1.0.0',
        py_modules=['jyw'],
        author='j',
        author_email='jiangyiwei@gmail.com',
        url='',
        description='An apple for eye',
    )
